@@ -1,4 +1,4 @@
-#!/usr/bin/python -b
+#!/usr/bin/env python
 # Copyright 2012-2018 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
@@ -22,12 +22,12 @@ import sys
 from portage.util._xattr import xattr
 
 
-_UNQUOTE_RE = re.compile(br"\\[0-7]{3}")
+_UNQUOTE_RE = re.compile(rb"\\[0-7]{3}")
 _FS_ENCODING = sys.getfilesystemencoding()
 
 
 def octal_quote_byte(b):
-    return ("\\%03o" % ord(b)).encode("ascii")
+    return (f"\\{ord(b):03o}").encode("ascii")
 
 
 def unicode_encode(s):
