@@ -33,9 +33,7 @@ class pkg_node(str):
 
 
 def pkg_desc_index_line_format(cp, pkgs, desc):
-    return "{} {}: {}\n".format(
-        cp, " ".join(_pkg_str(cpv).version for cpv in pkgs), desc
-    )
+    return f"{cp} {' '.join(_pkg_str(cpv).version for cpv in pkgs)}: {desc}\n"
 
 
 def pkg_desc_index_line_read(line, repo=None):
